@@ -54,17 +54,9 @@ printf("Starting level: '%s'\n",levelname);
 		printf("levelview not NULL\n");
 
 
-	tangle_view_load_now(TANGLE_VIEW(levelview)); //Needed for task-name
-	JammoGameLevel* game_level = JAMMO_GAME_LEVEL(jammo_get_object_by_id("game-level"));
-	if (game_level==NULL)
-		printf("game_level was NULL\n");
-	else
-		printf("game_level not NULL\n");
-
-	gchar* task_name = g_strdup_printf("%s-task1.json",levelname);
-	jammo_game_level_start_task(game_level,task_name);
-	g_free(task_name);
+	clutter_actor_set_name(levelview,levelname);
 	start_fullsequencer_gui(levelview);
+
 }
 
 
