@@ -40,11 +40,13 @@
 #include "../jammo-chum.h"
 #include "../jammo.h"
 #include "../jammo-miditrack-view.h"
+#include "../../cem/cem.h"
 
 #include "midi_editor.h"
 
 #include "slider_helper.h" //There are ranges for slider
 
+#include "sequencer.h"
 //We want disconnect this when leaving
 static gulong handler_for_sequencer_stop = 0;
 
@@ -131,7 +133,7 @@ keyboad name can be:
 	2= second row
 */
 static void visualize_playback(JammoInstrumentTrack* track, gint note, gpointer none) {
-	printf("visualize_playback: note_value: %d\n",note);
+	//printf("visualize_playback: note_value: %d\n",note);
 	gboolean sharp = FALSE;
 	gboolean bottom = FALSE;
 	gboolean event_off = FALSE;
@@ -220,7 +222,7 @@ static char notename_to_numericvalue(const gchar* name) {
 	if (name[1]=='s') //sharp
 		playable_note++;  //use next note-value
 
-	printf(" which means note-value: %d\n",playable_note);
+	//printf(" which means note-value: %d\n",playable_note);
 	return playable_note;
 }
 
@@ -230,7 +232,7 @@ i.e pressing and releasing
 */
 void instrument_key_interaction_notify (GObject *object, GParamSpec *pspec, gpointer user_data)  {
 		const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(object));
-		printf("Keyboard '%s' pressed\n",name);
+		//printf("Keyboard '%s' pressed\n",name);
 		TangleButton* button;
 
 		JammoInstrumentTrack* instrument_track;
@@ -253,7 +255,7 @@ void instrument_key_interaction_notify (GObject *object, GParamSpec *pspec, gpoi
 }
 
 void instrument_goeditor_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	printf("on_go_editor_button_clicked\n");
+	cem_add_to_log("GoTo midi-editor pressed",J_LOG_USER_ACTION);
 	end_jamming();
 
 	//start editor
@@ -266,11 +268,11 @@ static gulong handler_for_update_marker = 0;
 //slider-specific
 //---------------
 static void update_marker(JammoSliderTrack* track, gfloat frequency, gpointer none) {
-		printf("update_marker: '%p' Frequency %f\n",track,frequency);
+		//printf("update_marker: '%p' Frequency %f\n",track,frequency);
 		gfloat x = freq_to_coordinate(frequency);
 		if (frequency==0) //-> x=-inf
 			x=0.0;
-		printf("X: %f\n",x);
+		//printf("X: %f\n",x);
 		clutter_actor_set_x(CLUTTER_ACTOR(slider_marker),x);
 }
 
@@ -313,7 +315,7 @@ gboolean instrument_gui_slider_handler (ClutterActor *actor, ClutterEvent *event
 
 //TODO
 void instrument_metronome_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	printf("on_metronome_button_clicked\n");
+	cem_add_to_log("Metronome-button on virtual-instrument pressed (doesn't do anything yet)",J_LOG_USER_ACTION);
 }
 
 
@@ -339,10 +341,10 @@ static void end_jamming() {
 
 //TODO
 void instrument_mentor_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	printf("instrument MENTOR clicked\n");
+	cem_add_to_log("Mentor-button on virtual-instrument pressed (doesn't do anything yet)",J_LOG_USER_ACTION);
 }
 
-
+/*
 //TODO
 void instrument_gohome_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
 	printf("instrument_gohome_clicked\n");
@@ -352,31 +354,32 @@ void instrument_gohome_clicked (TangleAction *action, GObject *source, const gch
 	ClutterActor* view = jammo_get_actor_by_id("fullsequencer-view");
 	clutter_actor_show(view);
 }
+*/
 
 void instrument_gosequencer_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	printf("instrument_gosequencer_clicked\n");
+	cem_add_to_log("BackToSequencer-button on virtual-instrument pressed",J_LOG_USER_ACTION);
 	end_jamming();
 
 	//show sequencer
-	ClutterActor* view = jammo_get_actor_by_id("fullsequencer-view");
-	clutter_actor_show(view);
+	//ClutterActor* view = jammo_get_actor_by_id("fullsequencer-view");
+	//clutter_actor_show(view);
+	return_to_fullsequencer_gui();
 }
 
 void instrument_play_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	printf("play pressed\n");
-
+	cem_add_to_log("Play-button on virtual-instrument pressed",J_LOG_USER_ACTION);
 	if (recording) {
-		printf("STOPping recording first\n");
+		//printf("STOPping recording first\n");
 	jammo_sequencer_stop (JAMMO_SEQUENCER (static_sequencer));
 	}
 
 	if (playing) {
-		printf("Already playing -> stop\n");
+		//printf("Already playing -> stop\n");
 		jammo_sequencer_stop (JAMMO_SEQUENCER (static_sequencer));
 		return;
 	}
 
-	printf("Playing sequencer\n");
+	//printf("Playing sequencer\n");
 	playing=TRUE;
 	//If user has pressed play-button during record, we need handle this manually
 	tangle_button_set_selected(TANGLE_BUTTON(jammo_get_actor_by_id("instrument_play")),TRUE);
@@ -396,20 +399,19 @@ void instrument_play_clicked (TangleAction *action, GObject *source, const gchar
 
 
 void instrument_record_clicked (TangleButton *tanglebutton, gpointer user_data)  {
-	printf("on_record_button_clicked\n");
-
+	cem_add_to_log("Record-button on virtual-instrument pressed",J_LOG_USER_ACTION);
 	if (recording) {
-		printf("STOP recording\n");
+		//printf("STOP recording\n");
 		jammo_sequencer_stop (JAMMO_SEQUENCER (static_sequencer));
 		return;
 	}
 
 	if (playing) {
-		printf("STOP playing and start recording\n");
+		//printf("STOP playing and start recording\n");
 		jammo_sequencer_stop (JAMMO_SEQUENCER (static_sequencer));
 	}
 
-	printf("START recording\n");
+	//printf("START recording\n");
 	recording = TRUE;
 
 	//If user has pressed record-button during play, we need handle this manually
@@ -434,7 +436,7 @@ void instrument_record_clicked (TangleButton *tanglebutton, gpointer user_data)
 		g_signal_handler_disconnect (ad_hoc_slider_track,handler_for_update_marker);
 		handler_for_update_marker = g_signal_connect (static_slider_track, "report-current-frequency", G_CALLBACK (update_marker),NULL);
 
-		printf("Recording NOW\n");
+		cem_add_to_log("Virtual Instrument recording starts",J_LOG_INFO);
 	}
 
 
@@ -456,7 +458,7 @@ void instrument_record_clicked (TangleButton *tanglebutton, gpointer user_data)
 
 //TODO: this signal should be removed when changing view.
 static void instrument_gui_on_sequencer_stopped(JammoSequencer* sequencer, gpointer user_data) {
-	printf("instrument_gui_on_sequencer_stopped\n");
+	//printf("instrument_gui_on_sequencer_stopped\n");
 
 	//Slider:
 	if (static_jammo_miditrack_view==NULL) {
@@ -527,14 +529,14 @@ void instrument_gui_start (JammoMiditrackView* miditrack_view, TangleWidget* sli
 	static_jammo_miditrack_view = NULL;
 
 	if (slider_container){
-		printf("starting slider\n");
+		//printf("starting slider\n");
 		clutter_actor_hide(jammo_get_actor_by_id("instrument-two-rows-keyboard")); //this will also hide go_editor-button
 		clutter_actor_hide(jammo_get_actor_by_id("instrument-drumset"));
 
 
 		clutter_actor_show(jammo_get_actor_by_id("instrument-slider"));
 
-		static_slider_track = JAMMO_SLIDER_TRACK(g_object_get_data(G_OBJECT(slider_container),"track"));
+		g_object_get(slider_container,"track",&static_slider_track,NULL);
 
 		//Make ad-hoc-track using same type
 		int type;
