@@ -93,32 +93,61 @@ gboolean sequencer_change_to_bottom_view (TangleActor *actor, gpointer data) {
 	return TRUE;
 }
 
+//show-completed callback (=animation is ready)
+static void levelview_loaded(ClutterActor *levelview, gpointer none) {
+	g_signal_handlers_disconnect_by_func(levelview, levelview_loaded, NULL);
+	const gchar* levelname = clutter_actor_get_name(levelview);
+
+	//Make sample-buttons on wheel-game
+	//This can take time (thus we have hourglass on screen)
+	if (strcmp(levelname,"level1")==0)  //optimization: Level1 doesn't need them all.
+		sequencer_loop_tune_wheels(1);    //load only sample-buttons for level1
+	else
+		sequencer_loop_tune_wheels(0);    //load all sample-buttons
+
+
+	//Hide hourglass
+	ClutterActor* wait = jammo_get_actor_by_id("wait");
+	if (wait)
+		clutter_actor_hide(wait);
+
+	//Start task1 on this level
+	JammoGameLevel* game_level = JAMMO_GAME_LEVEL(jammo_get_object_by_id("game-level"));
+	if (game_level) {
+		gchar* task_name = g_strdup_printf("%s-task1.json",levelname);
+		jammo_game_level_start_task(game_level,task_name);
+		g_free(task_name);
+	}
+
+}
+
+
+
 static ClutterActor* current_levelview =NULL;
 void start_fullsequencer_gui(ClutterActor* levelview)
 {
+	tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
+
 	current_levelview=levelview;
 	cem_add_to_log("Sequencer GUI starts",J_LOG_INFO);
+
+	g_signal_connect(current_levelview, "show-completed", G_CALLBACK(levelview_loaded), NULL); //Continue after animated show
 	clutter_actor_show(current_levelview);
+
 	ClutterAction* action = tangle_actor_get_action_by_type(jammo_get_actor_by_id("fullsequencer-view-container"), TANGLE_TYPE_SCROLL_ACTION);
 	g_signal_connect_swapped(action, "clamp-offset-y", G_CALLBACK(tangle_widget_clamp_child_boundaries), jammo_get_actor_by_id("fullsequencer-view-container"));
 
 	static_sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 	static_metronome_track = NULL;
 
-	tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
-
-
-	JammoGameTask* task = jammo_game_level_get_active_task(JAMMO_GAME_LEVEL(jammo_get_object_by_id("game-level")));
-	JammoGameTask* task2 = JAMMO_GAME_TASK(jammo_get_object_by_id("level1-task1.json"));
-	if (task==task2)
-		sequencer_loop_tune_wheels(task);
-	else
-		sequencer_loop_tune_wheels(NULL);
-
 	sequencer_track_view_tune_width();
 
+	sequencer_change_to_sequencer_view(NULL,NULL); //Start to middle view. //TODO:do inside JSON
+
+	ClutterActor* wait = jammo_get_actor_by_id("wait");
+	if (wait)
+		clutter_actor_show(wait);
 
-	sequencer_change_to_sequencer_view(NULL,NULL); //Start to middle view.
 }
 
 void return_to_fullsequencer_gui(){
@@ -174,6 +203,10 @@ void fullsequencer_general_pitch_clicked(TangleButton *tanglebutton, gpointer us
 
 static void on_rendering_stopped(JammoSequencer* sequencer, gpointer none) {
 	cem_add_to_log("Rendering ready",J_LOG_INFO);
+	ClutterActor* wait = jammo_get_actor_by_id("wait");
+	if (wait)
+		clutter_actor_hide(wait);
+
 	g_signal_handlers_disconnect_by_func(sequencer, on_rendering_stopped, NULL);
 	if (!(jammo_sequencer_set_output_filename(sequencer, NULL))) {
 		cem_add_to_log("Problem going back to playback-mode after render",J_LOG_ERROR);
@@ -196,6 +229,10 @@ void sequencer_render_button_pressed (TangleButton* tanglebutton, gpointer none)
 	g_free(message);
 
 	if (jammo_sequencer_set_output_filename(static_sequencer, outputFilename)) {
+		ClutterActor* wait = jammo_get_actor_by_id("wait");
+		if (wait)
+			clutter_actor_show(wait);
+
 		g_signal_connect(static_sequencer, "stopped", G_CALLBACK(on_rendering_stopped), NULL);
 		jammo_sequencer_play(static_sequencer);
 	}
