@@ -743,7 +743,6 @@ static samplebutton_tuple effects[] = {
 
 
 
-#include "level1.h"
 //These tables are subsets of whole samplebuttons and used on level1-orientation game.
 static samplebutton_tuple level1_rhythms[] = {
 	{"wheel_game/acoustic_drumkit.png","wheel_game/Rh_8beat01_$t_44_1.ogg"},
@@ -779,7 +778,7 @@ loop_type:
 
 returns number of this type of sample_buttons
 */
-static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[], int loop_type, JammoGameTask* task) {
+static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[], int loop_type) {
 	samplebutton_tuple new_button=table[0];
 	int counter=0;
 	if (looper==NULL)
@@ -798,13 +797,6 @@ static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[],
 
 		int loop_id = counter+loop_type;
 
-		if (task){
-			gchar* act_name = g_strdup_printf("%d",counter+loop_type);
-			jammo_game_task_add_act(task, act_name);
-			g_signal_connect(sample_button,"listened", G_CALLBACK(level1_sample_button_on_wheel_listened),task);
-			g_free(act_name);
-		}
-
 		g_object_set(sample_button,"drag-threshold-y",10000,NULL); //No dragging by vertical-axis (it is for scrolling wheel)
 		g_signal_connect(sample_button,"drag-begin", G_CALLBACK(sample_button_drag_begin),NULL);
 
@@ -822,7 +814,7 @@ static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[],
 
 
 
-void sequencer_loop_tune_wheels(JammoGameTask* task) {
+void sequencer_loop_tune_wheels(int level_number) {
 	//Static controls-for-edit1$mute-button
 	ClutterActor* container = jammo_get_actor_by_id("fullsequencer_four_wheels");
 	if (container==NULL)
@@ -833,15 +825,15 @@ void sequencer_loop_tune_wheels(JammoGameTask* task) {
 	harmonical_sample_looper = tangle_widget_get_nth_child(TANGLE_WIDGET(container),2);
 	effect_sample_looper     = tangle_widget_get_nth_child(TANGLE_WIDGET(container),3);
 
-	if (task) { //We suppose that task!=NULL means level1-task1 (TODO: make proper check)
-		length_of_rhythms = add_sample_buttons(rhytmical_sample_looper,level1_rhythms,1000,task);
-		length_of_melodics = add_sample_buttons(melodical_sample_looper,level1_melodics,2000,task);
+	if (level_number==1) { //
+		length_of_rhythms = add_sample_buttons(rhytmical_sample_looper,level1_rhythms,1000);
+		length_of_melodics = add_sample_buttons(melodical_sample_looper,level1_melodics,2000);
 	}
 	else {
-		length_of_rhythms = add_sample_buttons(rhytmical_sample_looper,rhythms,1000,task);
-		length_of_melodics = add_sample_buttons(melodical_sample_looper,melodics,2000,task);
-		length_of_harmonics = add_sample_buttons(harmonical_sample_looper,harmonics,3000,task);
-		length_of_effects = add_sample_buttons(effect_sample_looper,effects,4000,task);
+		length_of_rhythms = add_sample_buttons(rhytmical_sample_looper,rhythms,1000);
+		length_of_melodics = add_sample_buttons(melodical_sample_looper,melodics,2000);
+		length_of_harmonics = add_sample_buttons(harmonical_sample_looper,harmonics,3000);
+		length_of_effects = add_sample_buttons(effect_sample_looper,effects,4000);
 	}
 
 	fine_tune_wheel(rhytmical_sample_looper);
