@@ -24,6 +24,7 @@ Call this: sequencer_track_view_tune_width
 #include "../jammo.h"
 #include "../jammo-cursor.h"
 #include "../save_helper.h"
+#include "../jammo-mentor.h"
 
 #include "sequencer_track_view.h"
 #include "sequencer.h"
@@ -97,6 +98,7 @@ gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpoin
 	}
 	else if  (JAMMO_IS_EDITING_TRACK_VIEW(track_view)){
 			printf(" it is editing_track (start jammer)\n");
+			tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
 			clutter_actor_show(jammo_get_actor_by_id("jammer-view"));
 			clutter_actor_hide(jammo_get_actor_by_id("fullsequencer-view"));
 			start_jammer();
